summaryrefslogtreecommitdiff
path: root/Makefile.SH
diff options
context:
space:
mode:
authorTony Cook <tony@develop-help.com>2011-09-29 15:43:02 +1000
committerTony Cook <tony@develop-help.com>2011-09-29 15:43:02 +1000
commit0961731461727bea7a75cf92326539ddb48cbfce (patch)
tree5d2cf707ff31489efa83f33cbfbf18ef8fb07b6a /Makefile.SH
parent45ed6be318926c8b79c4ab96ac82eac9f727de66 (diff)
downloadperl-0961731461727bea7a75cf92326539ddb48cbfce.tar.gz
Add darwin to the list of valgrind platforms
Diffstat (limited to 'Makefile.SH')
-rwxr-xr-xMakefile.SH8
1 files changed, 4 insertions, 4 deletions
diff --git a/Makefile.SH b/Makefile.SH
index 92300a4e26..fbd44ba90e 100755
--- a/Makefile.SH
+++ b/Makefile.SH
@@ -334,7 +334,7 @@ $make_set_make
!GROK!THIS!
case "${osname}" in
-linux*)
+linux*|darwin)
$spitshell >>$Makefile <<!GROK!THIS!
# If you're going to use valgrind and it can't be invoked as plain valgrind
# then you'll need to change this, or override it on the make command line.
@@ -892,9 +892,9 @@ quant$(PERL_EXE): $& perlmain$(OBJ_EXT) $(LIBPERL) $(static_ext) ext.libs $(PERL
!NO!SUBS!
case "${osname}${osvers}" in
-linux*)
+linux*|darwin*)
$spitshell >>$Makefile <<'!NO!SUBS!'
# Valgrind perl (currently Linux only)
perl.valgrind.config: config.sh
@echo "To build perl.valgrind you must Configure -Doptimize=-g -Uusemymalloc, checking..."
@@ -1454,7 +1454,7 @@ utest.utf16 ucheck.utf16: test_prep
!NO!SUBS!
case "${osname}${osvers}" in
-linux*)
+linux*|darwin*)
$spitshell >>$Makefile <<'!NO!SUBS!'
# Targets for valgrind testing:
@@ -892,9 +892,9 @@ quant$(PERL_EXE): $& perlmain$(OBJ_EXT) $(LIBPERL) $(static_ext) ext.libs $(PERL
$spitshell >>$Makefile <<'!NO!SUBS!'
-# Valgrind perl (currently Linux only)
+# Valgrind perl (currently Linux, Darwin only)
perl.valgrind.config: config.sh